
/*
 * m_setcur.c -- set "cur"
 *
 * $Id$
 */

#include <h/mh.h>


void
m_setcur (struct msgs *mp, int num)
{
    int i, public;

    public = mp->msgflags & READONLY ? 0 : 1;
    for (i = 0; mp->msgattrs[i]; i++)
	if (!strcmp (mp->msgattrs[i], current)) {
	    public = is_seq_private (mp, i) ? 0 : 1;
	    break;
	}

    if (!m_seqnew (mp, current, public))
	return;
    m_seqadd (mp, current, mp->curmsg = num, public);
}
